@@ -1,30 +1,37 @@
-use super::segments::SegmentIr;
+use super::segments::Segment;
 
 #[derive(Debug, Clone, PartialEq)]
-pub enum MacroIr<'a> {
+pub enum Macro<'a> {
     /// `@()`
     HtmlAttrs(Vec<Attr<'a>>),
     /// `@LOOSE`
     Loose,
     /// `@BULLET()`
     ListStyle(String),
-    /// `@TOC{}`
+    /// `@TOC`
     Toc,
     /// `@NOTOC`
     NoToc,
     /// `@NOTXT`
     NoText,
-    /// `@FOOTNOTES{}`
-    Footnotes(Vec<FootnoteIr<'a>>),
-    /// `@MATH_SCRIPT{}`
+    /// `@FOOTNOTES`
+    Footnotes(Vec<Footnote<'a>>),
+    /// `@MATH_SCRIPT`
     MathScript,
+    /// `@BLANK`
+    Blank,
+    /// `@CONFIG()`
+    Config,
+
+    /// `@INCLUDE(...)`
+    Include(&'a str),
 
     Invalid,
 }
 
-impl MacroIr<'_> {
+impl Macro<'_> {
     pub fn is_for_list(&self) -> bool {
-        matches!(self, MacroIr::Loose | MacroIr::ListStyle(_))
+        matches!(self, Macro::Loose | Macro::ListStyle(_))
     }
 }
 
@@ -41,7 +48,7 @@ pub enum AttrValue<'a> {
 }
 
 #[derive(Debug, Clone, PartialEq)]
-pub struct FootnoteIr<'a> {
+pub struct Footnote<'a> {
     pub num: u32,
-    pub text: Vec<SegmentIr<'a>>,
+    pub text: Vec<Segment<'a>>,
 }
